@@ -63,8 +63,8 @@ bool NestedListHelper::canIndent() const
     if ((textEdit->textCursor().block().isValid())
 //            && (  textEdit->textCursor().block().previous().isValid() )
         ) {
-        QTextBlock block = textEdit->textCursor().block();
-        QTextBlock prevBlock = textEdit->textCursor().block().previous();
+        const QTextBlock block = textEdit->textCursor().block();
+        const QTextBlock prevBlock = textEdit->textCursor().block().previous();
         if (block.textList()) {
             if (prevBlock.textList()) {
                 return block.textList()->format().indent() <= prevBlock.textList()->format().indent();
@@ -86,7 +86,7 @@ bool NestedListHelper::canDedent() const
             nextBlockIndent = nextBlock.textList()->format().indent();
         }
         if (thisBlock.textList()) {
-            int thisBlockIndent = thisBlock.textList()->format().indent();
+            const int thisBlockIndent = thisBlock.textList()->format().indent();
             if (thisBlockIndent >= nextBlockIndent) {
                 return thisBlockIndent > 0;
             }
@@ -118,7 +118,6 @@ bool NestedListHelper::handleAfterKeyPressEvent(QKeyEvent *event)
 
             // No need to reformatList in this case. reformatList is slow.
             if ((event->key() == Qt::Key_Return) || (event->key() == Qt::Key_Backspace)) {
-                reformatBoundingItemSpacing();
                 handled = true;
             }
         } else {
@@ -134,9 +133,9 @@ bool NestedListHelper::handleAfterDropEvent(QDropEvent *dropEvent)
     QTextCursor cursor = topOfSelection();
 
     QTextBlock droppedBlock = cursor.block();
-    int firstDroppedItemIndent = droppedBlock.textList()->format().indent();
+    const int firstDroppedItemIndent = droppedBlock.textList()->format().indent();
 
-    int minimumIndent = droppedBlock.previous().textList()->format().indent();
+    const int minimumIndent = droppedBlock.previous().textList()->format().indent();
 
     if (firstDroppedItemIndent < minimumIndent) {
         cursor = QTextCursor(droppedBlock);
@@ -155,14 +154,13 @@ bool NestedListHelper::handleAfterDropEvent(QDropEvent *dropEvent)
 //         list.add( droppedBlock );
     }
 
-    reformatBoundingItemSpacing();
     return true;
 }
 
 void NestedListHelper::processList(QTextList *list)
 {
     QTextBlock block = list->item(0);
-    int thisListIndent = list->format().indent();
+    const int thisListIndent = list->format().indent();
 
     QTextCursor cursor = QTextCursor(block);
     list = cursor.createList(list->format());
@@ -171,7 +169,7 @@ void NestedListHelper::processList(QTextList *list)
         block = block.next();
 
         QTextList *nextList = block.textList();
-        int nextItemIndent = nextList->format().indent();
+        const int nextItemIndent = nextList->format().indent();
         if (nextItemIndent < thisListIndent) {
             return;
         } else if (nextItemIndent > thisListIndent) {
@@ -192,7 +190,7 @@ void NestedListHelper::processList(QTextList *list)
 void NestedListHelper::reformatList(QTextBlock block)
 {
     if (block.textList()) {
-        int minimumIndent = block.textList()->format().indent();
+        const int minimumIndent = block.textList()->format().indent();
 
         // Start at the top of the list
         while (block.previous().textList() != nullptr) {
@@ -261,8 +259,6 @@ void NestedListHelper::handleOnIndentMore()
         cursor.createList(listFmt);
         reformatList();
     }
-
-    reformatBoundingItemSpacing();
 }
 
 void NestedListHelper::handleOnIndentLess()
@@ -272,8 +268,7 @@ void NestedListHelper::handleOnIndentLess()
     if (!currentList) {
         return;
     }
-    QTextListFormat listFmt;
-    listFmt = currentList->format();
+    QTextListFormat listFmt = currentList->format();
     if (listFmt.indent() > 1) {
         listFmt.setIndent(listFmt.indent() - 1);
         cursor.createList(listFmt);
@@ -284,7 +279,6 @@ void NestedListHelper::handleOnIndentLess()
         cursor.setBlockFormat(bfmt);
         reformatList(cursor.block().next());
     }
-    reformatBoundingItemSpacing();
 }
 
 void NestedListHelper::handleOnBulletType(int styleIndex)
@@ -311,72 +305,7 @@ void NestedListHelper::handleOnBulletType(int styleIndex)
         QTextBlockFormat bfmt;
         bfmt.setObjectIndex(-1);
         cursor.setBlockFormat(bfmt);
-        reformatBoundingItemSpacing();
     }
 
-    reformatBoundingItemSpacing();
     reformatList();
 }
-
-void NestedListHelper::reformatBoundingItemSpacing(QTextBlock block)
-{
-    // This is a workaround for qt bug 201228. Spacing between items is not kept
-    // consistent.
-    // Fixed scheduled for qt4.5
-    // -- Stephen Kelly, 8th June 2008
-
-    int nextBlockTopMargin = listNoMargin;
-    int previousBlockBottomMargin = listNoMargin;
-    int thisBlockBottomMargin = listBottomMargin;
-    int thisBlockTopMargin = listTopMargin;
-    bool prevBlockValid = block.previous().isValid();
-    bool nextBlockValid = block.next().isValid();
-
-    if (block.textList()) {
-        if (prevBlockValid && block.previous().textList()) {
-            thisBlockTopMargin = listNoMargin;
-        }
-
-        if (nextBlockValid && block.next().textList()) {
-            thisBlockBottomMargin = listNoMargin;
-        }
-    } else {
-        if (prevBlockValid && !block.previous().textList()) {
-            thisBlockTopMargin = listNoMargin;
-        }
-        if (nextBlockValid && !block.next().textList()) {
-            thisBlockBottomMargin = listNoMargin;
-        }
-    }
-    QTextBlockFormat fmt;
-    QTextCursor cursor;
-
-    fmt = block.blockFormat();
-    fmt.setBottomMargin(thisBlockBottomMargin);
-    fmt.setTopMargin(thisBlockTopMargin);
-    cursor = QTextCursor(block);
-    cursor.setBlockFormat(fmt);
-
-    if (nextBlockValid) {
-        block = block.next();
-        fmt = block.blockFormat();
-        fmt.setTopMargin(nextBlockTopMargin);
-        cursor = QTextCursor(block);
-        cursor.setBlockFormat(fmt);
-
-        block = block.previous();
-    }
-    if (prevBlockValid) {
-        block = block.previous();
-        fmt = block.blockFormat();
-        fmt.setBottomMargin(previousBlockBottomMargin);
-        cursor = QTextCursor(block);
-        cursor.setBlockFormat(fmt);
-    }
-}
-
-void NestedListHelper::reformatBoundingItemSpacing()
-{
-    reformatBoundingItemSpacing(topOfSelection().block());
-    reformatBoundingItemSpacing(bottomOfSelection().block());
-}
