@@ -57,16 +57,19 @@ public:
     RichTextComposerControler *composerControler = nullptr;
     RichTextComposerActions *richTextComposerActions = nullptr;
     KPIMTextEdit::RichTextExternalComposer *externalComposer = nullptr;
-    RichTextComposer *q = nullptr;
+    RichTextComposer *const q;
     RichTextComposer::Mode mode = RichTextComposer::Plain;
     bool forcePlainTextMarkup = false;
     struct UndoHtmlVersion {
         QString originalHtml;
         QString plainText;
-        Q_REQUIRED_RESULT bool isValid() const {
+        Q_REQUIRED_RESULT bool isValid() const
+        {
             return !originalHtml.isEmpty() && !plainText.isEmpty();
         }
-        void clear() {
+
+        void clear()
+        {
             originalHtml.clear();
             plainText.clear();
         }
@@ -118,9 +121,7 @@ QVector<QAction *> RichTextComposer::richTextActionList() const
 
 void RichTextComposer::setEnableActions(bool state)
 {
-    for (QAction *act : richTextActionList()) {
-        act->setEnabled(state);
-    }
+    d->richTextComposerActions->setActionsEnabled(state);
 }
 
 void RichTextComposer::createActions(KActionCollection *ac)
@@ -282,8 +283,8 @@ void RichTextComposer::activateRichText()
         if (d->undoHtmlVersion.isValid() && (toPlainText() == d->undoHtmlVersion.plainText)) {
             setHtml(d->undoHtmlVersion.originalHtml);
             d->undoHtmlVersion.clear();
-        } else {
 #if 0 //Need to investigate it
+        } else {
             //try to import markdown
 #if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
             document()->setMarkdown(toPlainText(), QTextDocument::MarkdownDialectCommonMark);
@@ -335,8 +336,8 @@ void RichTextComposer::evaluateReturnKeySupport(QKeyEvent *event)
 {
     if (event->key() == Qt::Key_Return) {
         QTextCursor cursor = textCursor();
-        int oldPos = cursor.position();
-        int blockPos = cursor.block().position();
+        const int oldPos = cursor.position();
+        const int blockPos = cursor.block().position();
 
         //selection all the line.
         cursor.movePosition(QTextCursor::StartOfBlock);
@@ -400,10 +401,38 @@ void RichTextComposer::evaluateListSupport(QKeyEvent *event)
         handled = d->composerControler->nestedListHelper()->handleBeforeKeyPressEvent(event);
     }
 
+    // If a line was merged with previous (next) one, with different heading level,
+    // the style should also be adjusted accordingly (i.e. merged)
+    if ((event->key() == Qt::Key_Backspace && textCursor().atBlockStart()
+         && (textCursor().blockFormat().headingLevel() != textCursor().block().previous().blockFormat().headingLevel()))
+        || (event->key() == Qt::Key_Delete && textCursor().atBlockEnd()
+            && (textCursor().blockFormat().headingLevel() != textCursor().block().next().blockFormat().headingLevel()))) {
+        QTextCursor cursor = textCursor();
+        cursor.beginEditBlock();
+        if (event->key() == Qt::Key_Delete) {
+            cursor.deleteChar();
+        } else {
+            cursor.deletePreviousChar();
+        }
+        d->composerControler->setHeadingLevel(cursor.blockFormat().headingLevel());
+        cursor.endEditBlock();
+        handled = true;
+    }
+
     if (!handled) {
         KPIMTextEdit::RichTextEditor::keyPressEvent(event);
     }
 
+    // Match the behavior of office suites: newline after header switches to normal text
+    if ((event->key() == Qt::Key_Return)
+        && (textCursor().blockFormat().headingLevel() > 0)
+        && (textCursor().atBlockEnd())) {
+        // it should be undoable together with actual "return" keypress
+        textCursor().joinPreviousEditBlock();
+        d->composerControler->setHeadingLevel(0);
+        textCursor().endEditBlock();
+    }
+
     if (textCursor().currentList()) {
         d->composerControler->nestedListHelper()->handleAfterKeyPressEvent(event);
     }
