@@ -85,6 +85,8 @@ public:
     QAction *action_format_reset = nullptr;
 
     KToggleAction *action_format_painter = nullptr;
+    KSelectAction *action_heading_level = nullptr;
+    KToggleAction *action_list_checkbox = nullptr;
 
     bool richTextEnabled = false;
 };
@@ -467,6 +469,37 @@ void RichTextComposerActions::createActions(KActionCollection *ac)
     connect(d->action_format_painter, &QAction::toggled,
             d->composerControler, &RichTextComposerControler::slotFormatPainter);
 
+    d->action_heading_level = new KSelectAction(i18nc("@title:menu", "Heading Level"), this);
+    const QStringList headingLevels = {i18nc("@item:inmenu no heading", "Basic text"),
+                                       i18nc("@item:inmenu heading level 1 (largest)", "Title"),
+                                       i18nc("@item:inmenu heading level 2", "Subtitle"),
+                                       i18nc("@item:inmenu heading level 3", "Section"),
+                                       i18nc("@item:inmenu heading level 4", "Subsection"),
+                                       i18nc("@item:inmenu heading level 5", "Paragraph"),
+                                       i18nc("@item:inmenu heading level 6 (smallest)", "Subparagraph")};
+
+    d->action_heading_level->setItems(headingLevels);
+    d->action_heading_level->setCurrentItem(0);
+    d->richTextActionList.append(d->action_heading_level);
+    d->action_heading_level->setObjectName(QStringLiteral("format_heading_level"));
+    connect(d->action_heading_level, QOverload<int>::of(&KSelectAction::triggered),
+            this, &RichTextComposerActions::setHeadingLevel);
+    if (ac) {
+        ac->addAction(QStringLiteral("format_heading_level"), d->action_heading_level);
+    }
+
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
+    d->action_list_checkbox = new KToggleAction(QIcon::fromTheme(QStringLiteral("checkbox")),
+                                                i18nc("@action", "Checkbox"), this);
+    d->richTextActionList.append(d->action_list_checkbox);
+    d->action_list_checkbox->setObjectName(QStringLiteral("format_list_checkbox"));
+    connect(d->action_list_checkbox, &KToggleAction::toggled,
+            d->composerControler, &RichTextComposerControler::addCheckbox);
+    if (ac) {
+        ac->addAction(QStringLiteral("format_list_checkbox"), d->action_list_checkbox);
+    }
+#endif
+
     disconnect(d->composerControler->richTextComposer(), &QTextEdit::currentCharFormatChanged,
                this, &RichTextComposerActions::slotUpdateCharFormatActions);
     disconnect(d->composerControler->richTextComposer(), &QTextEdit::cursorPositionChanged,
@@ -486,10 +519,15 @@ void RichTextComposerActions::updateActionStates()
     slotUpdateCharFormatActions(d->composerControler->richTextComposer()->currentCharFormat());
 }
 
+void RichTextComposerActions::setHeadingLevel(int level)
+{
+    d->composerControler->setHeadingLevel(level);
+    slotUpdateMiscActions();
+}
+
 void RichTextComposerActions::setListStyle(int _styleindex)
 {
     d->composerControler->setListStyle(_styleindex);
-    //Needed ?
     slotUpdateMiscActions();
 }
 
@@ -498,8 +536,6 @@ void RichTextComposerActions::setActionsEnabled(bool enabled)
     for (QAction *action : qAsConst(d->richTextActionList)) {
         action->setEnabled(enabled);
     }
-    //Use all the time emojiunicode
-    //d->action_add_emoticon->setEmojiPlainText(!enabled);
     d->richTextEnabled = enabled;
 }
 
@@ -522,7 +558,8 @@ void RichTextComposerActions::slotUpdateCharFormatActions(const QTextCharFormat
 
 void RichTextComposerActions::slotUpdateMiscActions()
 {
-    const Qt::Alignment a = d->composerControler->richTextComposer()->alignment();
+    const RichTextComposer *richTextComposer = d->composerControler->richTextComposer();
+    const Qt::Alignment a = richTextComposer->alignment();
     if (a & Qt::AlignLeft) {
         d->action_align_left->setChecked(true);
     } else if (a & Qt::AlignHCenter) {
@@ -532,8 +569,8 @@ void RichTextComposerActions::slotUpdateMiscActions()
     } else if (a & Qt::AlignJustify) {
         d->action_align_justify->setChecked(true);
     }
-    if (d->composerControler->richTextComposer()->textCursor().currentList()) {
-        d->action_list_style->setCurrentItem(-d->composerControler->richTextComposer()->textCursor().currentList()->format().style());
+    if (richTextComposer->textCursor().currentList()) {
+        d->action_list_style->setCurrentItem(-richTextComposer->textCursor().currentList()->format().style());
     } else {
         d->action_list_style->setCurrentItem(0);
     }
@@ -548,9 +585,13 @@ void RichTextComposerActions::slotUpdateMiscActions()
         d->action_list_dedent->setEnabled(false);
     }
 
-    const Qt::LayoutDirection direction = d->composerControler->richTextComposer()->textCursor().blockFormat().layoutDirection();
+    const Qt::LayoutDirection direction = richTextComposer->textCursor().blockFormat().layoutDirection();
     d->action_direction_ltr->setChecked(direction == Qt::LeftToRight);
     d->action_direction_rtl->setChecked(direction == Qt::RightToLeft);
+    d->action_heading_level->setCurrentItem(richTextComposer->textCursor().blockFormat().headingLevel());
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
+    d->action_list_checkbox->setChecked(richTextComposer->textCursor().blockFormat().marker() != QTextBlockFormat::MarkerType::NoMarker);
+#endif
 }
 
 void RichTextComposerActions::uncheckActionFormatPainter()
@@ -560,5 +601,7 @@ void RichTextComposerActions::uncheckActionFormatPainter()
 
 void RichTextComposerActions::textModeChanged(KPIMTextEdit::RichTextComposer::Mode mode)
 {
-    d->action_add_table->setRichTextMode(mode == KPIMTextEdit::RichTextComposer::Rich);
+    if (d->action_add_table) {
+        d->action_add_table->setRichTextMode(mode == KPIMTextEdit::RichTextComposer::Rich);
+    }
 }
