@@ -36,6 +36,7 @@
 #include <QClipboard>
 #include <QIcon>
 #include <QTextDocumentFragment>
+#include <QTextList>
 #include "textutils.h"
 #include "insertimagedialog.h"
 
@@ -69,7 +70,7 @@ public:
     void selectLinkText(QTextCursor *cursor) const;
     void fixupTextEditString(QString &text) const;
     void mergeFormatOnWordOrSelection(const QTextCharFormat &format);
-    QString addQuotesToText(const QString &inputText, const QString &defaultQuoteSign);
+    Q_REQUIRED_RESULT QString addQuotesToText(const QString &inputText, const QString &defaultQuoteSign);
     void updateLink(const QString &linkUrl, const QString &linkText);
     QFont saveFont;
     QColor mLinkColor;
@@ -77,7 +78,7 @@ public:
     NestedListHelper *nestedListHelper = nullptr;
     RichTextComposer *richtextComposer = nullptr;
     RichTextComposerImages *richTextImages = nullptr;
-    RichTextComposerControler *q = nullptr;
+    RichTextComposerControler *const q;
     bool painterActive = false;
 };
 
@@ -85,7 +86,7 @@ void RichTextComposerControler::RichTextComposerControlerPrivate::selectLinkText
 {
     // If the cursor is on a link, select the text of the link.
     if (cursor->charFormat().isAnchor()) {
-        QString aHref = cursor->charFormat().anchorHref();
+        const QString aHref = cursor->charFormat().anchorHref();
 
         // Move cursor to start of link
         while (cursor->charFormat().anchorHref() == aHref) {
@@ -157,6 +158,29 @@ bool RichTextComposerControler::painterActive() const
     return d->painterActive;
 }
 
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
+void RichTextComposerControler::addCheckbox(bool add)
+{
+    QTextBlockFormat fmt;
+    fmt.setMarker(add ? QTextBlockFormat::MarkerType::Unchecked : QTextBlockFormat::MarkerType::NoMarker);
+    QTextCursor cursor = richTextComposer()->textCursor();
+    cursor.beginEditBlock();
+    if (add && !cursor.currentList()) {
+        // Checkbox only works with lists, so if we are not at list, add a new one
+        setListStyle(1);
+    } else if (!add && cursor.currentList() && cursor.currentList()->count() == 1) {
+        // If this is a single-element list with a checkbox, and user disables
+        // a checkbox, assume user don't want a list too
+        // (so when cursor is not on a list, and enables checkbox and disables
+        // it right after, he returns to the same state with no list)
+        setListStyle(0);
+    }
+    cursor.mergeBlockFormat(fmt);
+    cursor.endEditBlock();
+}
+
+#endif
+
 void RichTextComposerControler::setFontForWholeText(const QFont &font)
 {
     QTextCharFormat fmt;
@@ -208,9 +232,9 @@ void RichTextComposerControler::insertHorizontalRule()
     cursor.beginEditBlock();
     cursor.insertHtml(QStringLiteral("<hr>"));
     cursor.insertBlock(bf, cf);
+    cursor.endEditBlock();
     richTextComposer()->setTextCursor(cursor);
     richTextComposer()->activateRichText();
-    cursor.endEditBlock();
 }
 
 void RichTextComposerControler::alignLeft()
@@ -362,6 +386,48 @@ void RichTextComposerControler::setTextSubScript(bool subscript)
     richTextComposer()->activateRichText();
 }
 
+void RichTextComposerControler::setHeadingLevel(int level)
+{
+    const int boundedLevel = qBound(0, 6, level);
+    // Apparently, 5 is maximum for FontSizeAdjustment; otherwise level=1 and
+    // level=2 look the same
+    const int sizeAdjustment = boundedLevel > 0 ? 5 - boundedLevel : 0;
+
+    QTextCursor cursor = richTextComposer()->textCursor();
+    cursor.beginEditBlock();
+
+    QTextBlockFormat blkfmt;
+    blkfmt.setHeadingLevel(boundedLevel);
+    cursor.mergeBlockFormat(blkfmt);
+
+    QTextCharFormat chrfmt;
+    chrfmt.setFontWeight(boundedLevel > 0 ? QFont::Bold : QFont::Normal);
+    chrfmt.setProperty(QTextFormat::FontSizeAdjustment, sizeAdjustment);
+    // Applying style to the current line or selection
+    QTextCursor selectCursor = cursor;
+    if (selectCursor.hasSelection()) {
+        QTextCursor top = selectCursor;
+        top.setPosition(qMin(top.anchor(), top.position()));
+        top.movePosition(QTextCursor::StartOfBlock);
+
+        QTextCursor bottom = selectCursor;
+        bottom.setPosition(qMax(bottom.anchor(), bottom.position()));
+        bottom.movePosition(QTextCursor::EndOfBlock);
+
+        selectCursor.setPosition(top.position(), QTextCursor::MoveAnchor);
+        selectCursor.setPosition(bottom.position(), QTextCursor::KeepAnchor);
+    } else {
+        selectCursor.select(QTextCursor::BlockUnderCursor);
+    }
+    selectCursor.mergeCharFormat(chrfmt);
+
+    cursor.mergeBlockCharFormat(chrfmt);
+    cursor.endEditBlock();
+    richTextComposer()->setTextCursor(cursor);
+    richTextComposer()->setFocus();
+    richTextComposer()->activateRichText();
+}
+
 void RichTextComposerControler::setChangeTextForegroundColor()
 {
     const QColor currentColor = richTextComposer()->textColor();
@@ -607,43 +673,6 @@ void RichTextComposerControler::insertLink(const QString &url)
     }
 }
 
-void RichTextComposerControler::insertShareLink(const QString &url)
-{
-    if (url.isEmpty()) {
-        return;
-    }
-    const QString msg = i18n("I've linked 1 file to this email:");
-    if (richTextComposer()->textMode() == RichTextComposer::Rich) {
-        QTextCursor cursor = richTextComposer()->textCursor();
-
-        cursor.beginEditBlock();
-        cursor.insertText(QLatin1Char('\n') + msg + QLatin1Char('\n'));
-
-        QTextCharFormat format = cursor.charFormat();
-        // Save original format to create an extra space with the existing char
-        // format for the block
-        const QTextCharFormat originalFormat = format;
-        // Add link details
-        format.setAnchor(true);
-        format.setAnchorHref(url);
-        // Workaround for QTBUG-1814:
-        // Link formatting does not get applied immediately when setAnchor(true)
-        // is called.  So the formatting needs to be applied manually.
-        format.setUnderlineStyle(QTextCharFormat::SingleUnderline);
-        format.setUnderlineColor(d->linkColor());
-        format.setForeground(d->linkColor());
-        // Insert link text specified in dialog, otherwise write out url.
-        cursor.insertText(url, format);
-
-        cursor.setPosition(cursor.selectionEnd());
-        cursor.setCharFormat(originalFormat);
-        cursor.insertText(QStringLiteral(" \n"));
-        cursor.endEditBlock();
-    } else {
-        richTextComposer()->textCursor().insertText(QLatin1Char('\n') + msg + QLatin1Char('\n') + url + QLatin1Char('\n'));
-    }
-}
-
 void RichTextComposerControler::setCursorPositionFromStart(unsigned int pos)
 {
     if (pos > 0) {
@@ -906,15 +935,15 @@ QString RichTextComposerControler::toWrappedPlainText() const
 QString RichTextComposerControler::toWrappedPlainText(QTextDocument *doc) const
 {
     QString temp;
-    QRegularExpression rx(QStringLiteral("(http|ftp|ldap)s?\\S+-$"));
+    static const QRegularExpression rx(QStringLiteral("(http|ftp|ldap)s?\\S+-$"));
     QTextBlock block = doc->begin();
     while (block.isValid()) {
         QTextLayout *layout = block.layout();
         const int numberOfLine(layout->lineCount());
         bool urlStart = false;
         for (int i = 0; i < numberOfLine; ++i) {
-            QTextLine line = layout->lineAt(i);
-            QString lineText = block.text().mid(line.textStart(), line.textLength());
+            const QTextLine line = layout->lineAt(i);
+            const QString lineText = block.text().mid(line.textStart(), line.textLength());
 
             if (lineText.contains(rx)
                 || (urlStart && !lineText.contains(QLatin1Char(' '))
