@@ -50,7 +50,6 @@ public:
     Q_REQUIRED_RESULT bool canDedentList() const;
 
     Q_REQUIRED_RESULT NestedListHelper *nestedListHelper() const;
-    void insertShareLink(const QString &url);
     void insertLink(const QString &url);
     void setCursorPositionFromStart(unsigned int pos);
     void ensureCursorVisible();
@@ -58,7 +57,7 @@ public:
     RichTextComposerImages *composerImages() const;
     Q_REQUIRED_RESULT bool painterActive() const;
     void disablePainter();
-    bool isFormattingUsed() const;
+    Q_REQUIRED_RESULT bool isFormattingUsed() const;
 
     void setFontForWholeText(const QFont &font);
     void textModeChanged(KPIMTextEdit::RichTextComposer::Mode mode);
@@ -68,7 +67,11 @@ public:
     Q_REQUIRED_RESULT QString toCleanPlainText(const QString &plainText = QString()) const;
     void addQuotes(const QString &defaultQuote);
 public Q_SLOTS:
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
+    void addCheckbox(bool add = true);
+#endif
     void insertHorizontalRule();
+    void setHeadingLevel(int level);
     void alignLeft();
     void alignCenter();
     void alignRight();
