@@ -31,12 +31,13 @@ class RichTextComposer;
  */
 class KPIMTEXTEDIT_EXPORT RichTextComposerEmailQuoteDecorator : public Sonnet::SpellCheckDecorator
 {
+    Q_OBJECT
 public:
     explicit RichTextComposerEmailQuoteDecorator(RichTextComposer *textEdit);
     ~RichTextComposerEmailQuoteDecorator() override;
 
 protected:
-    bool isSpellCheckingEnabledForBlock(const QString &blockText) const override;
+    Q_REQUIRED_RESULT bool isSpellCheckingEnabledForBlock(const QString &blockText) const override;
 private:
     class RichTextComposerEmailQuoteDecoratorPrivate;
     RichTextComposerEmailQuoteDecoratorPrivate *const d;
