@@ -28,6 +28,7 @@
 #include <KMessageBox>
 #include <KLocalizedString>
 #include <QFileInfo>
+#include <QRandomGenerator>
 
 using namespace KPIMTextEdit;
 
@@ -81,6 +82,9 @@ void RichTextComposerImages::addImageHelper(const QUrl &url, int width, int heig
         = fi.baseName().isEmpty()
           ? QStringLiteral("image.png")
           : QString(fi.baseName() + QLatin1String(".png"));
+    if (width != -1 && height != -1 && (image.width() > width && image.height() > height)) {
+        image = image.scaled(width, height);
+    }
     addImageHelper(imageName, image, width, height);
 }
 
@@ -166,7 +170,7 @@ ImageWithNameList RichTextComposerImages::imagesWithName() const
 {
     ImageWithNameList retImages;
     QStringList seenImageNames;
-    const QList<QTextImageFormat> imageFormats = embeddedImageFormats();
+    const QVector<QTextImageFormat> imageFormats = embeddedImageFormats();
     for (const QTextImageFormat &imageFormat : imageFormats) {
         const QString name = imageFormat.name();
         if (!seenImageNames.contains(name)) {
@@ -184,10 +188,10 @@ ImageWithNameList RichTextComposerImages::imagesWithName() const
     return retImages;
 }
 
-QList< QSharedPointer<EmbeddedImage> > RichTextComposerImages::embeddedImages() const
+QVector< QSharedPointer<EmbeddedImage> > RichTextComposerImages::embeddedImages() const
 {
     const ImageWithNameList normalImages = imagesWithName();
-    QList< QSharedPointer<EmbeddedImage> > retImages;
+    QVector< QSharedPointer<EmbeddedImage> > retImages;
     retImages.reserve(normalImages.count());
     for (const ImageWithNamePtr &normalImage : normalImages) {
         retImages.append(createEmbeddedImage(normalImage->image, normalImage->name));
@@ -201,18 +205,17 @@ QSharedPointer<EmbeddedImage> RichTextComposerImages::createEmbeddedImage(const
     buffer.open(QIODevice::WriteOnly);
     img.save(&buffer, "PNG");
 
-    qsrand(QDateTime::currentDateTimeUtc().toSecsSinceEpoch() + qHash(imageName));
     QSharedPointer<EmbeddedImage> embeddedImage(new EmbeddedImage());
     embeddedImage->image = KCodecs::Codec::codecForName("base64")->encode(buffer.buffer());
     embeddedImage->imageName = imageName;
-    embeddedImage->contentID = QStringLiteral("%1@KDE").arg(qrand());
+    embeddedImage->contentID = QStringLiteral("%1@KDE").arg(QRandomGenerator::global()->generate64());
     return embeddedImage;
 }
 
-QList<QTextImageFormat> RichTextComposerImages::embeddedImageFormats() const
+QVector<QTextImageFormat> RichTextComposerImages::embeddedImageFormats() const
 {
     QTextDocument *doc = d->composer->document();
-    QList<QTextImageFormat> retList;
+    QVector<QTextImageFormat> retList;
 
     QTextBlock currentBlock = doc->begin();
     while (currentBlock.isValid()) {
@@ -222,7 +225,7 @@ QList<QTextImageFormat> RichTextComposerImages::embeddedImageFormats() const
                 QTextImageFormat imageFormat = fragment.charFormat().toImageFormat();
                 if (imageFormat.isValid()) {
                     //TODO: Replace with a way to see if an image is an embedded image or a remote
-                    QUrl url(imageFormat.name());
+                    const QUrl url(imageFormat.name());
                     if (!url.isValid() || !url.scheme().startsWith(QLatin1String("http"))) {
                         retList.append(imageFormat);
                     }
