@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -23,16 +23,15 @@
 
 #include <QTextCursor>
 
-namespace KPIMTextEdit
-{
+namespace KPIMTextEdit {
 class KPIMTEXTEDIT_EXPORT EditorUtil
 {
 public:
     EditorUtil();
-    void upperCase(QTextCursor &cursor);
-    void lowerCase(QTextCursor &cursor);
-    void sentenceCase(QTextCursor &cursor);
-    void reverseCase(QTextCursor &cursor);
+    void upperCase(QTextCursor &cursor) const;
+    void lowerCase(QTextCursor &cursor) const;
+    void sentenceCase(QTextCursor &cursor) const;
+    void reverseCase(QTextCursor &cursor) const;
 };
 }
 
