@@ -51,6 +51,8 @@ MarkupDirector::~MarkupDirector()
     delete d_ptr;
 }
 
+//#define ADD_HEADER_SUPPORT 1
+
 QTextFrame::iterator
 MarkupDirector::processBlockContents(QTextFrame::iterator frameIt, const QTextBlock &block)
 {
@@ -60,7 +62,13 @@ MarkupDirector::processBlockContents(QTextFrame::iterator frameIt, const QTextBl
     const auto blockAlignment = blockFormat.alignment();
 
     // TODO: decide when to use <h1> etc.
-
+#ifdef ADD_HEADER_SUPPORT
+    if (blockFormat.headingLevel() > 0) {
+        //Header
+        qDebug() << " header " << blockFormat.headingLevel();
+        m_builder->beginHeader(blockFormat.headingLevel());
+    }
+#endif
     if (blockFormat.hasProperty(QTextFormat::BlockTrailingHorizontalRulerWidth)) {
         m_builder->insertHorizontalRule();
         if (!frameIt.atEnd()) {
@@ -242,7 +250,7 @@ MarkupDirector::processFragment(QTextBlock::iterator it, const QTextFragment &fr
 
 
 void MarkupDirector::processDocumentContents(QTextFrame::iterator start,
-                                             QTextFrame::iterator end)
+                                             const QTextFrame::iterator &end)
 {
     while (!start.atEnd() && start != end) {
         auto frame = start.currentFrame();
@@ -312,7 +320,7 @@ QTextFrame::iterator MarkupDirector::processTable(QTextFrame::iterator it,
 
     const auto headerRowCount = format.headerRowCount();
 
-    QList<QTextTableCell> alreadyProcessedCells;
+    QVector<QTextTableCell> alreadyProcessedCells;
 
     for (int row = 0, total = table->rows(); row < total; ++row) {
         // Put a thead element around here somewhere?
@@ -475,7 +483,7 @@ MarkupDirector::skipBlockGroup(QTextFrame::iterator it,
 }
 
 QPair<QTextFrame::iterator, QTextBlock>
-MarkupDirector::processBlockGroup(QTextFrame::iterator it,
+MarkupDirector::processBlockGroup(const QTextFrame::iterator &it,
                                   const QTextBlock &block,
                                   QTextBlockGroup *blockGroup)
 {
@@ -520,7 +528,7 @@ MarkupDirector::processImage(QTextBlock::iterator it,
     return it;
 }
 
-void MarkupDirector::processClosingElements(QTextBlock::iterator it)
+void MarkupDirector::processClosingElements(const QTextBlock::iterator &it)
 {
     Q_D(MarkupDirector);
     // The order of closing elements is determined by the order they were opened
@@ -596,7 +604,7 @@ void MarkupDirector::processClosingElements(QTextBlock::iterator it)
     }
 }
 
-void MarkupDirector::processOpeningElements(QTextBlock::iterator it)
+void MarkupDirector::processOpeningElements(const QTextBlock::iterator &it)
 {
     Q_D(MarkupDirector);
     auto fragment = it.fragment();
@@ -675,7 +683,7 @@ void MarkupDirector::processOpeningElements(QTextBlock::iterator it)
     }
 }
 
-QSet<int> MarkupDirector::getElementsToClose(QTextBlock::iterator it) const
+QSet<int> MarkupDirector::getElementsToClose(const QTextBlock::iterator &it) const
 {
     Q_D(const MarkupDirector);
     QSet<int> closedElements;
@@ -788,7 +796,7 @@ QSet<int> MarkupDirector::getElementsToClose(QTextBlock::iterator it) const
     return closedElements;
 }
 
-QList<int> MarkupDirector::getElementsToOpen(QTextBlock::iterator it)
+QList<int> MarkupDirector::getElementsToOpen(const QTextBlock::iterator &it)
 {
     Q_D(MarkupDirector);
     auto fragment = it.fragment();
