@@ -19,13 +19,14 @@
 
 #include "plaintexteditfindbar.h"
 #include "texteditor/commonwidget/textfindreplacewidget.h"
+#include "texteditor/commonwidget/findutils.h"
 
-#include <KMessageBox>
 #include <KColorScheme>
+#include <KLocalizedString>
 
-#include <QLineEdit>
 #include <QRegularExpression>
 #include <QPlainTextEdit>
+#include <QLineEdit>
 
 using namespace KPIMTextEdit;
 
@@ -74,15 +75,6 @@ bool PlainTextEditFindBar::searchInDocument(const QString &text, QTextDocument::
     return found;
 }
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 13, 0)
-bool PlainTextEditFindBar::searchInDocument(const QRegExp &regExp, QTextDocument::FindFlags searchOptions)
-{
-    const bool found = d->mView->find(regExp, searchOptions);
-    mFindWidget->setFoundMatch(found);
-    return found;
-}
-
-#else
 bool PlainTextEditFindBar::searchInDocument(const QRegularExpression &regExp, QTextDocument::FindFlags searchOptions)
 {
     const bool found = d->mView->find(regExp, searchOptions);
@@ -90,8 +82,6 @@ bool PlainTextEditFindBar::searchInDocument(const QRegularExpression &regExp, QT
     return found;
 }
 
-#endif
-
 void PlainTextEditFindBar::autoSearchMoveCursor()
 {
     QTextCursor cursor = d->mView->textCursor();
@@ -122,12 +112,6 @@ void PlainTextEditFindBar::slotReplaceText()
 
 void PlainTextEditFindBar::slotReplaceAllText()
 {
-    QString newText;
-    if (mFindWidget->isRegularExpression()) {
-        newText = d->mView->toPlainText().replace(mFindWidget->searchRegExp(), mReplaceWidget->replaceLineEdit()->text());
-    } else {
-        newText = d->mView->toPlainText().replace(mFindWidget->searchText(), mReplaceWidget->replaceLineEdit()->text());
-    }
-    d->mView->selectAll();
-    d->mView->insertPlainText(newText);
+    const int count = FindUtils::replaceAll(d->mView->document(), mFindWidget, mReplaceWidget);
+    Q_EMIT displayMessageIndicator(i18np("%1 replacement made", "%1 replacements made", count));
 }
