@@ -19,16 +19,17 @@
 
 #include "richtexteditfindbar.h"
 #include "texteditor/commonwidget/textfindreplacewidget.h"
+#include "texteditor/commonwidget/findutils.h"
 
-#include <KMessageBox>
 #include <KColorScheme>
+#include <KLocalizedString>
 
 #include <QTextEdit>
 #include <QLineEdit>
 #include <QRegularExpression>
 
 using namespace KPIMTextEdit;
-class KPIMTextEdit::RichTextEditFindBarPrivate
+class Q_DECL_HIDDEN KPIMTextEdit::RichTextEditFindBarPrivate
 {
 public:
     RichTextEditFindBarPrivate(QTextEdit *view)
@@ -73,15 +74,6 @@ bool RichTextEditFindBar::searchInDocument(const QString &text, QTextDocument::F
     return found;
 }
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 13, 0)
-bool RichTextEditFindBar::searchInDocument(const QRegExp &regExp, QTextDocument::FindFlags searchOptions)
-{
-    const bool found = d->mView->find(regExp, searchOptions);
-    mFindWidget->setFoundMatch(found);
-    return found;
-}
-
-#else
 bool RichTextEditFindBar::searchInDocument(const QRegularExpression &regExp, QTextDocument::FindFlags searchOptions)
 {
     const bool found = d->mView->find(regExp, searchOptions);
@@ -89,8 +81,6 @@ bool RichTextEditFindBar::searchInDocument(const QRegularExpression &regExp, QTe
     return found;
 }
 
-#endif
-
 void RichTextEditFindBar::autoSearchMoveCursor()
 {
     QTextCursor cursor = d->mView->textCursor();
@@ -122,12 +112,6 @@ void RichTextEditFindBar::slotReplaceText()
 
 void RichTextEditFindBar::slotReplaceAllText()
 {
-    QString newText;
-    if (mFindWidget->isRegularExpression()) {
-        newText = d->mView->toPlainText().replace(mFindWidget->searchRegExp(), mReplaceWidget->replaceLineEdit()->text());
-    } else {
-        newText = d->mView->toPlainText().replace(mFindWidget->searchText(), mReplaceWidget->replaceLineEdit()->text());
-    }
-    d->mView->selectAll();
-    d->mView->insertPlainText(newText);
+    const int count = FindUtils::replaceAll(d->mView->document(), mFindWidget, mReplaceWidget);
+    Q_EMIT displayMessageIndicator(i18np("%1 replacement made", "%1 replacements made", count));
 }
