@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2019 Laurent Montel <montel@kde.org>
+   Copyright (C) 2014-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -24,7 +24,7 @@
 #include <QVBoxLayout>
 #include <QDialogButtonBox>
 #include <QPushButton>
-#include <kconfiggroup.h>
+#include <KConfigGroup>
 #include <KSharedConfig>
 
 using namespace KPIMTextEdit;
@@ -32,7 +32,7 @@ using namespace KPIMTextEdit;
 TextToSpeechConfigDialog::TextToSpeechConfigDialog(QWidget *parent)
     : QDialog(parent)
 {
-    setWindowTitle(i18n("Configure Text-To-Speech"));
+    setWindowTitle(i18nc("@title:window", "Configure Text-To-Speech"));
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
     mTextToSpeechConfigWidget = new TextToSpeechConfigWidget(parent);
     mainLayout->addWidget(mTextToSpeechConfigWidget);
